@@ -139,6 +139,15 @@ class DevOpsGuruClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client/#can_paginate)
         """
 
+    def delete_insight(self, *, Id: str) -> Dict[str, Any]:
+        """
+        Deletes the insight along with the associated anomalies, events and
+        recommendations.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Client.delete_insight)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client/#delete_insight)
+        """
+
     def describe_account_health(self) -> DescribeAccountHealthResponseTypeDef:
         """
         Returns the number of open reactive insights, the number of open proactive
@@ -171,8 +180,8 @@ class DevOpsGuruClient(BaseClient):
 
     def describe_event_sources_config(self) -> DescribeEventSourcesConfigResponseTypeDef:
         """
-        This operation lists details about a DevOps Guru event source that is shared
-        with your account.
+        Returns the integration status of services that are integrated with DevOps Guru
+        as Consumer via EventBridge.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Client.describe_event_sources_config)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client/#describe_event_sources_config)
@@ -447,7 +456,8 @@ class DevOpsGuruClient(BaseClient):
         self, *, EventSources: "EventSourcesConfigTypeDef" = ...
     ) -> Dict[str, Any]:
         """
-        Updates the event source configuration.
+        Enables or disables integration with a service that can be integrated with
+        DevOps Guru.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Client.update_event_sources_config)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client/#update_event_sources_config)
